summaryrefslogtreecommitdiff
path: root/src/lib
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2018-07-19 14:36:04 +0100
committerCarl Hetherington <cth@carlh.net>2018-07-19 23:45:23 +0100
commit507a389e9c5f84ec1d51e7566e38fbf42f658537 (patch)
tree5387a0ae0555126fd278b3ab6b496bb3cd8f9fb3 /src/lib
parent491176352b80bea000564e6662738722185be721 (diff)
PlainText -> PlainTextFile.
Diffstat (limited to 'src/lib')
-rw-r--r--src/lib/content_factory.cc6
-rw-r--r--src/lib/decoder_factory.cc8
-rw-r--r--src/lib/plain_text_file.cc (renamed from src/lib/plain_text.cc)10
-rw-r--r--src/lib/plain_text_file.h (renamed from src/lib/plain_text.h)18
-rw-r--r--src/lib/plain_text_file_content.cc (renamed from src/lib/plain_text_content.cc)20
-rw-r--r--src/lib/plain_text_file_content.h (renamed from src/lib/plain_text_content.h)16
-rw-r--r--src/lib/plain_text_file_decoder.cc (renamed from src/lib/plain_text_decoder.cc)17
-rw-r--r--src/lib/plain_text_file_decoder.h (renamed from src/lib/plain_text_decoder.h)17
-rw-r--r--src/lib/wscript6
9 files changed, 63 insertions, 55 deletions
diff --git a/src/lib/content_factory.cc b/src/lib/content_factory.cc
index 4e8880ffe..167b3f4e9 100644
--- a/src/lib/content_factory.cc
+++ b/src/lib/content_factory.cc
@@ -26,7 +26,7 @@
#include "audio_content.h"
#include "image_content.h"
#include "atmos_mxf_content.h"
-#include "plain_text_content.h"
+#include "plain_text_file_content.h"
#include "dcp_content.h"
#include "dcp_text_content.h"
#include "util.h"
@@ -88,7 +88,7 @@ content_factory (shared_ptr<const Film> film, cxml::NodePtr node, int version, l
);
} else if (type == "SubRip" || type == "TextSubtitle") {
- content.reset (new PlainTextContent (film, node, version));
+ content.reset (new PlainTextFileContent (film, node, version));
} else if (type == "DCP") {
content.reset (new DCPContent (film, node, version));
} else if (type == "DCPSubtitle") {
@@ -210,7 +210,7 @@ content_factory (shared_ptr<const Film> film, boost::filesystem::path path)
if (valid_image_file (path)) {
single.reset (new ImageContent (film, path));
} else if (ext == ".srt" || ext == ".ssa" || ext == ".ass") {
- single.reset (new PlainTextContent (film, path));
+ single.reset (new PlainTextFileContent (film, path));
} else if (ext == ".xml") {
cxml::Document doc;
doc.read_file (path);
diff --git a/src/lib/decoder_factory.cc b/src/lib/decoder_factory.cc
index 73a5b66fe..a7367dd24 100644
--- a/src/lib/decoder_factory.cc
+++ b/src/lib/decoder_factory.cc
@@ -24,8 +24,8 @@
#include "dcp_decoder.h"
#include "image_content.h"
#include "image_decoder.h"
-#include "plain_text_content.h"
-#include "plain_text_decoder.h"
+#include "plain_text_file_content.h"
+#include "plain_text_file_decoder.h"
#include "dcp_text_content.h"
#include "dcp_text_decoder.h"
#include "video_mxf_content.h"
@@ -54,9 +54,9 @@ decoder_factory (shared_ptr<const Content> content, shared_ptr<Log> log, bool fa
return shared_ptr<Decoder> (new ImageDecoder (ic, log));
}
- shared_ptr<const PlainTextContent> rc = dynamic_pointer_cast<const PlainTextContent> (content);
+ shared_ptr<const PlainTextFileContent> rc = dynamic_pointer_cast<const PlainTextFileContent> (content);
if (rc) {
- return shared_ptr<Decoder> (new PlainTextDecoder (rc, log));
+ return shared_ptr<Decoder> (new PlainTextFileDecoder (rc, log));
}
shared_ptr<const DCPTextContent> dsc = dynamic_pointer_cast<const DCPTextContent> (content);
diff --git a/src/lib/plain_text.cc b/src/lib/plain_text_file.cc
index 58035a07f..4ed13491c 100644
--- a/src/lib/plain_text.cc
+++ b/src/lib/plain_text_file.cc
@@ -18,10 +18,10 @@
*/
-#include "plain_text.h"
+#include "plain_text_file.h"
#include "cross.h"
#include "exceptions.h"
-#include "plain_text_content.h"
+#include "plain_text_file_content.h"
#include <sub/subrip_reader.h>
#include <sub/ssa_reader.h>
#include <sub/collect.h>
@@ -39,7 +39,7 @@ using boost::scoped_array;
using boost::optional;
using dcp::Data;
-PlainText::PlainText (shared_ptr<const PlainTextContent> content)
+PlainTextFile::PlainTextFile (shared_ptr<const PlainTextFileContent> content)
{
Data in (content->path (0));
@@ -96,7 +96,7 @@ PlainText::PlainText (shared_ptr<const PlainTextContent> content)
/** @return time of first subtitle, if there is one */
optional<ContentTime>
-PlainText::first () const
+PlainTextFile::first () const
{
if (_subtitles.empty()) {
return optional<ContentTime>();
@@ -106,7 +106,7 @@ PlainText::first () const
}
ContentTime
-PlainText::length () const
+PlainTextFile::length () const
{
if (_subtitles.empty ()) {
return ContentTime ();
diff --git a/src/lib/plain_text.h b/src/lib/plain_text_file.h
index 01d3d77ef..34dc08465 100644
--- a/src/lib/plain_text.h
+++ b/src/lib/plain_text_file.h
@@ -1,5 +1,5 @@
/*
- Copyright (C) 2014-2016 Carl Hetherington <cth@carlh.net>
+ Copyright (C) 2014-2018 Carl Hetherington <cth@carlh.net>
This file is part of DCP-o-matic.
@@ -18,24 +18,30 @@
*/
-#ifndef DCPOMATIC_TEXT_SUBTITLE_H
-#define DCPOMATIC_TEXT_SUBTITLE_H
+#ifndef DCPOMATIC_PLAIN_TEXT_FILE_H
+#define DCPOMATIC_PLAIN_TEXT_FILE_H
#include "dcpomatic_time.h"
#include <sub/subtitle.h>
#include <boost/shared_ptr.hpp>
#include <vector>
-class PlainTextContent;
+class PlainTextFileContent;
class plain_text_time_test;
class plain_text_coordinate_test;
class plain_text_content_test;
class plain_text_parse_test;
-class PlainText
+/** @class PlainTextFile
+ * @brief Base for PlainTextFile decoder and examiner.
+ *
+ * In fact this is sufficient for the examiner, so it's used as-is rather than deriving
+ * a pointless PlainTextFileExaminer.
+ */
+class PlainTextFile
{
public:
- explicit PlainText (boost::shared_ptr<const PlainTextContent>);
+ explicit PlainTextFile (boost::shared_ptr<const PlainTextFileContent>);
boost::optional<ContentTime> first () const;
ContentTime length () const;
diff --git a/src/lib/plain_text_content.cc b/src/lib/plain_text_file_content.cc
index a07dcb67c..2b52cee96 100644
--- a/src/lib/plain_text_content.cc
+++ b/src/lib/plain_text_file_content.cc
@@ -18,9 +18,9 @@
*/
-#include "plain_text_content.h"
+#include "plain_text_file_content.h"
#include "util.h"
-#include "plain_text.h"
+#include "plain_text_file.h"
#include "film.h"
#include "font.h"
#include "text_content.h"
@@ -35,13 +35,13 @@ using std::cout;
using boost::shared_ptr;
using dcp::raw_convert;
-PlainTextContent::PlainTextContent (shared_ptr<const Film> film, boost::filesystem::path path)
+PlainTextFileContent::PlainTextFileContent (shared_ptr<const Film> film, boost::filesystem::path path)
: Content (film, path)
{
subtitle.reset (new TextContent (this));
}
-PlainTextContent::PlainTextContent (shared_ptr<const Film> film, cxml::ConstNodePtr node, int version)
+PlainTextFileContent::PlainTextFileContent (shared_ptr<const Film> film, cxml::ConstNodePtr node, int version)
: Content (film, node)
, _length (node->number_child<ContentTime::Type> ("Length"))
{
@@ -49,10 +49,10 @@ PlainTextContent::PlainTextContent (shared_ptr<const Film> film, cxml::ConstNode
}
void
-PlainTextContent::examine (boost::shared_ptr<Job> job)
+PlainTextFileContent::examine (boost::shared_ptr<Job> job)
{
Content::examine (job);
- PlainText s (shared_from_this ());
+ PlainTextFile s (shared_from_this ());
/* Default to turning these subtitles on */
subtitle->set_use (true);
@@ -63,19 +63,19 @@ PlainTextContent::examine (boost::shared_ptr<Job> job)
}
string
-PlainTextContent::summary () const
+PlainTextFileContent::summary () const
{
return path_summary() + " " + _("[subtitles]");
}
string
-PlainTextContent::technical_summary () const
+PlainTextFileContent::technical_summary () const
{
return Content::technical_summary() + " - " + _("Text subtitles");
}
void
-PlainTextContent::as_xml (xmlpp::Node* node, bool with_paths) const
+PlainTextFileContent::as_xml (xmlpp::Node* node, bool with_paths) const
{
node->add_child("Type")->add_child_text ("TextSubtitle");
Content::as_xml (node, with_paths);
@@ -88,7 +88,7 @@ PlainTextContent::as_xml (xmlpp::Node* node, bool with_paths) const
}
DCPTime
-PlainTextContent::full_length () const
+PlainTextFileContent::full_length () const
{
FrameRateChange const frc (active_video_frame_rate(), film()->video_frame_rate ());
return DCPTime (_length, frc);
diff --git a/src/lib/plain_text_decoder.cc b/src/lib/plain_text_file_decoder.cc
index 005d30669..40a605963 100644
--- a/src/lib/plain_text_decoder.cc
+++ b/src/lib/plain_text_file_decoder.cc
@@ -1,5 +1,5 @@
/*
- Copyright (C) 2014-2016 Carl Hetherington <cth@carlh.net>
+ Copyright (C) 2014-2018 Carl Hetherington <cth@carlh.net>
This file is part of DCP-o-matic.
@@ -18,9 +18,10 @@
*/
-#include "plain_text_decoder.h"
-#include "plain_text_content.h"
+#include "plain_text_file_decoder.h"
+#include "plain_text_file_content.h"
#include "text_content.h"
+#include "text_decoder.h"
#include <dcp/subtitle_string.h>
#include <boost/foreach.hpp>
#include <iostream>
@@ -34,8 +35,8 @@ using boost::shared_ptr;
using boost::optional;
using boost::dynamic_pointer_cast;
-PlainTextDecoder::PlainTextDecoder (shared_ptr<const PlainTextContent> content, shared_ptr<Log> log)
- : PlainText (content)
+PlainTextFileDecoder::PlainTextFileDecoder (shared_ptr<const PlainTextFileContent> content, shared_ptr<Log> log)
+ : PlainTextFile (content)
, _next (0)
{
ContentTime first;
@@ -46,7 +47,7 @@ PlainTextDecoder::PlainTextDecoder (shared_ptr<const PlainTextContent> content,
}
void
-PlainTextDecoder::seek (ContentTime time, bool accurate)
+PlainTextFileDecoder::seek (ContentTime time, bool accurate)
{
/* It's worth back-tracking a little here as decoding is cheap and it's nice if we don't miss
too many subtitles when seeking.
@@ -65,7 +66,7 @@ PlainTextDecoder::seek (ContentTime time, bool accurate)
}
bool
-PlainTextDecoder::pass ()
+PlainTextFileDecoder::pass ()
{
if (_next >= _subtitles.size ()) {
return true;
@@ -79,7 +80,7 @@ PlainTextDecoder::pass ()
}
ContentTimePeriod
-PlainTextDecoder::content_time_period (sub::Subtitle s) const
+PlainTextFileDecoder::content_time_period (sub::Subtitle s) const
{
return ContentTimePeriod (
ContentTime::from_seconds (s.from.all_as_seconds()),
diff --git a/src/lib/plain_text_decoder.h b/src/lib/plain_text_file_decoder.h
index f11fe3eab..ea64a294b 100644
--- a/src/lib/plain_text_decoder.h
+++ b/src/lib/plain_text_file_decoder.h
@@ -1,5 +1,5 @@
/*
- Copyright (C) 2014-2016 Carl Hetherington <cth@carlh.net>
+ Copyright (C) 2014-2018 Carl Hetherington <cth@carlh.net>
This file is part of DCP-o-matic.
@@ -18,18 +18,19 @@
*/
-#ifndef DCPOMATIC_TEXT_SUBTITLE_DECODER_H
-#define DCPOMATIC_TEXT_SUBTITLE_DECODER_H
+#ifndef DCPOMATIC_PLAIN_TEXT_FILE_DECODER_H
+#define DCPOMATIC_PLAIN_TEXT_FILE_DECODER_H
-#include "text_decoder.h"
-#include "plain_text.h"
+#include "plain_text_file.h"
+#include "decoder.h"
-class PlainText;
+class PlainTextFileContent;
+class Log;
-class PlainTextDecoder : public Decoder, public PlainText
+class PlainTextFileDecoder : public Decoder, public PlainTextFile
{
public:
- PlainTextDecoder (boost::shared_ptr<const PlainTextContent>, boost::shared_ptr<Log> log);
+ PlainTextFileDecoder (boost::shared_ptr<const PlainTextFileContent>, boost::shared_ptr<Log> log);
void seek (ContentTime time, bool accurate);
bool pass ();
diff --git a/src/lib/wscript b/src/lib/wscript
index dd7c87f39..9e2d07d7c 100644
--- a/src/lib/wscript
+++ b/src/lib/wscript
@@ -134,9 +134,9 @@ sources = """
string_log_entry.cc
text_content.cc
text_decoder.cc
- plain_text.cc
- plain_text_content.cc
- plain_text_decoder.cc
+ plain_text_file.cc
+ plain_text_file_content.cc
+ plain_text_file_decoder.cc
timer.cc
transcode_job.cc
types.cc
diff --git a/src/lib/plain_text_content.h b/src/lib/plain_text_file_content.h
index 02b4596ed..603931e4c 100644
--- a/src/lib/plain_text_content.h
+++ b/src/lib/plain_text_file_content.h
@@ -1,5 +1,5 @@
/*
- Copyright (C) 2014-2016 Carl Hetherington <cth@carlh.net>
+ Copyright (C) 2014-2018 Carl Hetherington <cth@carlh.net>
This file is part of DCP-o-matic.
@@ -22,17 +22,17 @@
class Job;
/** @class PlainText
* @brief SubRip or SSA subtitles.
*/
-class PlainTextContent : public Content
+class PlainTextFileContent : public Content
{
public:
- PlainTextContent (boost::shared_ptr<const Film>, boost::filesystem::path);
- PlainTextContent (boost::shared_ptr<const Film>, cxml::ConstNodePtr, int);
+ PlainTextFileContent (boost::shared_ptr<const Film>, boost::filesystem::path);
+ PlainTextFileContent (boost::shared_ptr<const Film>, cxml::ConstNodePtr, int);
- boost::shared_ptr<PlainTextContent> shared_from_this () {
- return boost::dynamic_pointer_cast<PlainTextContent> (Content::shared_from_this ());
+ boost::shared_ptr<PlainTextFileContent> shared_from_this () {
+ return boost::dynamic_pointer_cast<PlainTextFileContent> (Content::shared_from_this ());
}
void examine (boost::shared_ptr<Job>);
@@ -22,17 +22,17 @@
class Job;
-/** @class PlainText
- * @brief SubRip or SSA subtitles.
+/** @class PlainTextFileContent
+ * @brief A SubRip, SSA or ASS file.
*/